@@ -1,4 +1,4 @@
-predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=TRUE,offset,...){
+predict.lognet=function(object,newx,s=NULL,type=c("link","response","coefficients","class","nonzero"),exact=FALSE,offset,...){
   type=match.arg(type)
     ### remember that although the fortran lognet makes predictions
   ### for the first class, we make predictions for the second class
